@@ -2,6 +2,7 @@
 
 from pathlib import Path
 from typing import Any, Dict, Optional, Union, List, Iterable
+from datetime import datetime
 
 from singer_sdk import typing as th  # JSON Schema typing helpers
 
@@ -172,6 +173,26 @@ class ReportsStream(GoogleAdsStream):
     def gaql(self):
         raise NotImplementedError
 
+    @property
+    def start_date(self):
+        start_date = self.config["start_date"]
+        format_date = datetime.strptime(start_date, "%Y-%m-%dT%H:%M:%SZ").strftime(
+            "%Y-%m-%d"
+        )
+        return format_date
+
+    @property
+    def end_date(self):
+        end_date = self.config["end_date"]
+        format_date = datetime.strptime(end_date, "%Y-%m-%dT%H:%M:%SZ").strftime(
+            "%Y-%m-%d"
+        )
+        return format_date
+
+    @property
+    def between_filter(self):
+        return f"BETWEEN '{self.start_date}' AND '{self.end_date}'"
+
     @property
     def path(self):
         # Paramas
@@ -244,12 +265,15 @@ class AdGroupsStream(ReportsStream):
 class AdGroupsPerformance(ReportsStream):
     """AdGroups Performance"""
 
-    gaql = """
-        SELECT campaign.id, ad_group.id, metrics.impressions, metrics.clicks,
+    @property
+    def gaql(self) -> str:
+        return f"""
+            SELECT campaign.id, ad_group.id, metrics.impressions, metrics.clicks,
                metrics.cost_micros
                FROM ad_group
-               WHERE segments.date DURING LAST_7_DAYS
+               WHERE segments.date {self.between_filter}
         """
+
     records_jsonpath = "$.results[*]"
     name = "adgroupsperformance"
     primary_keys = ["id"]
@@ -260,9 +284,12 @@ class AdGroupsPerformance(ReportsStream):
 class CampaignPerformance(ReportsStream):
     """Campaign Performance"""
 
-    gaql = """
-    SELECT campaign.name, campaign.status, segments.device, segments.date, metrics.impressions, metrics.clicks, metrics.ctr, metrics.average_cpc, metrics.cost_micros FROM campaign WHERE segments.date DURING LAST_7_DAYS
-    """
+    @property
+    def gaql(self) -> str:
+        return f"""
+            SELECT campaign.name, campaign.status, segments.device, segments.date, metrics.impressions, metrics.clicks, metrics.ctr, metrics.average_cpc, metrics.cost_micros FROM campaign WHERE segments.date {self.between_filter}
+        """
+
     records_jsonpath = "$.results[*]"
     name = "campaign_performance"
     primary_keys = ["id"]
@@ -273,9 +300,12 @@ class CampaignPerformance(ReportsStream):
 class CampaignPerformanceByAgeRangeAndDevice(ReportsStream):
     """Campaign Performance By Age Range and Device"""
 
-    gaql = """
-    SELECT ad_group_criterion.age_range.type, campaign.name, campaign.status, ad_group.name, segments.date, segments.device, ad_group_criterion.system_serving_status, ad_group_criterion.bid_modifier, metrics.clicks, metrics.impressions, metrics.ctr, metrics.average_cpc, metrics.cost_micros, campaign.advertising_channel_type FROM age_range_view WHERE segments.date DURING LAST_7_DAYS
-    """
+    @property
+    def gaql(self) -> str:
+        return f"""
+            SELECT ad_group_criterion.age_range.type, campaign.name, campaign.status, ad_group.name, segments.date, segments.device, ad_group_criterion.system_serving_status, ad_group_criterion.bid_modifier, metrics.clicks, metrics.impressions, metrics.ctr, metrics.average_cpc, metrics.cost_micros, campaign.advertising_channel_type FROM age_range_view WHERE segments.date {self.between_filter}
+        """
+
     records_jsonpath = "$.results[*]"
     name = "campaign_performance_by_age_range_and_device"
     primary_keys = ["id"]
@@ -286,9 +316,12 @@ class CampaignPerformanceByAgeRangeAndDevice(ReportsStream):
 class CampaignPerformanceByGenderAndDevice(ReportsStream):
     """Campaign Performance By Age Range and Device"""
 
-    gaql = """
-    SELECT ad_group_criterion.gender.type, campaign.name, campaign.status, ad_group.name, segments.date, segments.device, ad_group_criterion.system_serving_status, ad_group_criterion.bid_modifier, metrics.clicks, metrics.impressions, metrics.ctr, metrics.average_cpc, metrics.cost_micros, campaign.advertising_channel_type FROM gender_view WHERE segments.date DURING LAST_7_DAYS
-    """
+    @property
+    def gaql(self) -> str:
+        return f"""
+            SELECT ad_group_criterion.gender.type, campaign.name, campaign.status, ad_group.name, segments.date, segments.device, ad_group_criterion.system_serving_status, ad_group_criterion.bid_modifier, metrics.clicks, metrics.impressions, metrics.ctr, metrics.average_cpc, metrics.cost_micros, campaign.advertising_channel_type FROM gender_view WHERE segments.date {self.between_filter}
+        """
+
     records_jsonpath = "$.results[*]"
     name = "campaign_performance_by_gender_and_device"
     primary_keys = ["id"]
@@ -299,9 +332,12 @@ class CampaignPerformanceByGenderAndDevice(ReportsStream):
 class CampaignPerformanceByLocation(ReportsStream):
     """Campaign Performance By Age Range and Device"""
 
-    gaql = """
-    SELECT campaign_criterion.location.geo_target_constant, campaign.name, campaign_criterion.bid_modifier, segments.date, metrics.clicks, metrics.impressions, metrics.ctr, metrics.average_cpc, metrics.cost_micros FROM location_view WHERE segments.date DURING LAST_7_DAYS AND campaign_criterion.status != 'REMOVED'
-    """
+    @property
+    def gaql(self) -> str:
+        return f"""
+            SELECT campaign_criterion.location.geo_target_constant, campaign.name, campaign_criterion.bid_modifier, segments.date, metrics.clicks, metrics.impressions, metrics.ctr, metrics.average_cpc, metrics.cost_micros FROM location_view WHERE segments.date {self.between_filter} AND campaign_criterion.status != 'REMOVED'
+        """
+
     records_jsonpath = "$.results[*]"
     name = "campaign_performance_by_location"
     primary_keys = ["id"]
@@ -312,15 +348,17 @@ class CampaignPerformanceByLocation(ReportsStream):
 class ConversionsByLocation(ReportsStream):
     """Conversions By Location"""
 
-    gaql = """
-    SELECT campaign_criterion.location.geo_target_constant, campaign.name, campaign_criterion.bid_modifier, segments.date, segments.conversion_action_category, metrics.conversions FROM location_view WHERE segments.date DURING LAST_7_DAYS AND campaign_criterion.status != 'REMOVED'
-    """
+    @property
+    def gaql(self) -> str:
+        return f"SELECT campaign_criterion.location.geo_target_constant, campaign.name, campaign_criterion.bid_modifier, segments.date, segments.conversion_action_category, metrics.conversions FROM location_view WHERE segments.date {self.between_filter} AND campaign_criterion.status != 'REMOVED'"
+
     records_jsonpath = "$.results[*]"
     name = "conversion_by_location"
     primary_keys = ["id"]
     replication_key = None
     schema_filepath = SCHEMAS_DIR / "conversion_by_location.json"
 
+
 class CampaignLabel(ReportsStream):
     """Conversions By Location"""
 
